Usage — molecular-simulations 2025 documentation

# Usage

## Installation

To use molecular-simulations, first install it using pip:

## Examples

     1from molecular_simulations.build import ExplicitSolvent
     2from molecular_simulations.simulate import Simulator
     3from pathlib import Path
     4
     5input_pdb = Path('protein.pdb').resolve()
     6builder = ExplicitSolvent(input_pdb)
     7builder.build()
     8
     9sim = Simulator(builder.out, builder.out.with_suffix('.inpcrd'))
    10sim.run()